@@ -14,7 +14,16 @@ for jar in $LIB_DIR/*.jar; do
  fi
 done
 
-java -Xmx1024m -cp $CP \
+JAVACMD=java
+if [ -n "$JAVA_HOME" ]; then
+  if [ -x "$JAVA_HOME/jre/bin/java" ]; then
+    JAVACMD="$JAVA_HOME/jre/bin/java"
+  else
+    JAVACMD="$JAVA_HOME/bin/java"
+  fi
+fi
+
+$JAVACMD -Xmx1024m -cp $CP \
     -Djava.util.logging.config.file=$LOGGING_PROPERTIES \
     -Dwdic-fonts.properties=$FONTS_PROPERTIES \
     -Dwdic-chars.properties=$CHARS_PROPERTIES \
